import { creatLabel, creatPolygon } from "@/pages/BMap/common";

import { useEffect, useRef } from "react";
import { renderToStaticMarkup } from "react-dom/server";
import data from "./demoData.json";
import styles from "./index.module.css";

/**
 * 区域图层
 */

export default function Polygon({ map }) {
  const coveringRef = useRef([]);

  useEffect(() => {
    if (map) {
      initLayer();
    }
    return () => {
      clearLayer();
    };
  }, [map]);

  const listScore = [
    {
      name: "锦江区",
      v: 93.6,
    },
    {
      name: "温江区",
      v: 97.3,
    },
    {
      name: "金牛区",
      v: 96.6,
    },
    {
      name: "都江堰市",
      v: 92.7,
    },
    {
      name: "武侯区",
      v: 97.2,
    },
    {
      name: "青白江区",
      v: 98.2,
    },
    {
      name: "简阳市",
      v: 92.0,
    },
    {
      name: "天府新区",
      v: 95.4,
    },
    {
      name: "成华区",
      v: 90.9,
    },
    {
      name: "大邑县",
      v: 90.5,
    },
    {
      name: "双流区",
      v: 90.2,
    },
    {
      name: "彭州市",
      v: 88.9,
    },
    {
      name: "蒲江县",
      v: 88.2,
    },
    {
      name: "龙泉驿区",
      v: 96.5,
    },
    {
      name: "崇州市",
      v: 86.4,
    },
    {
      name: "郫都区",
      v: 84.7,
    },
    {
      name: "邛崃市",
      v: 83.8,
    },
    {
      name: "高新区",
      v: 83.3,
    },
    {
      name: "青羊区",
      v: 83.1,
    },
    {
      name: "新都区",
      v: 98.6,
    },
    {
      name: "金堂县",
      v: 81.2,
    },
    {
      name: "锦江区",
      v: 93.6,
    },
    {
      name: "新津县",
      v: 79.8,
    },
  ];
  const initLayer = () => {
    let path = [];
    data.features.forEach((item) => {
      let num = listScore.find((v) => v.name === item.properties.name)?.v ?? 90;
      let color = getRandomHexColor(num);
      let points = item.geometry.coordinates[0][0].map((v) => {
        return new BMapGL.Point(v[0], v[1]);
      });
      let polygon = creatPolygon(points, {
        strokeColor: "#fff",
        strokeWeight: 2,
        fillColor: color,
        fillOpacity: 1,
      });
      path = [...path, ...points];
      let label = creatLabel(
        renderToStaticMarkup(
          <>
            <span className={styles.mkWrap}>
              <span className={styles.marker} style={{ borderColor: color }}>
                {num}
              </span>
              <p className={styles.label}>{item.properties.name}</p>
            </span>
          </>
        ),
        {
          position: new BMapGL.Point(
            item.properties.center[0],
            item.properties.center[1]
          ),
          offset: new BMapGL.Size(-20, -20),
          style: {
            background: "transparent",
            border: 0,
          },
        }
      );
      coveringRef.current.push(polygon, label);
      map?.addOverlay(polygon);
      map?.addOverlay(label);
    });
    //郫都区旁白又一块空白区域，填充其颜色
    let blankArea = [
      [104.00974142087979, 30.680418328517767],
      [103.8720892555806, 30.78392522273836],
      [104.03061991022197, 30.85512089973781],
      [104.1212368182825, 30.732941925242507],
    ];
    let a = blankArea.map((v) => {
      return new BMapGL.Point(v[0], v[1]);
    });
    let blankPolygon = creatPolygon(a, {
      strokeColor: "#fff",
      strokeWeight: 2,
      fillColor: "#ffa250",
      fillOpacity: 1,
    });
    blankPolygon?.setZIndex(-1);
    coveringRef.current.push(blankPolygon);
    map?.addOverlay(blankPolygon);

    map?.setViewport(path, {
      zoomFactor: 0.42,
      margins: [35, 0, 0, 0],
    });
  };

  function getRandomHexColor(val) {
    if (val < 60) {
      return "#fa6875";
    } else if (val < 85) {
      return "#ffa250";
    } else if (val <= 95) {
      return "#0680f4";
    } else if (val > 95) {
      return "#09c35c";
    }
  }

  const clearLayer = () => {
    if (coveringRef.current) {
      coveringRef.current.forEach((v) => {
        map?.removeOverlay(v);
      });
    }
  };
  return null;
}
