import { useUnmount } from "ahooks";
import classNames from "classnames";
import { memo, useEffect, useLayoutEffect, useMemo, useRef } from "react";
import { Map, MapApiLoaderHOC } from "react-bmapgl";
import AreaPolygon from "./Layers/AreaPolygon";
import mapStyle from "./mapStyle/mapStyle_map_config.json";
import styles from "./index.module.css";
import icon from "@/assets/images/icon.png";
import icon4 from "@/assets/images/icon4.png";

const BMap = memo(() => {
  const MapRef = useRef(null);

  useUnmount(() => {
    if (MapRef.current) {
      MapRef.current?.map?.clearOverlays();
      MapRef.current?.map?.destroy();
      MapRef.current = null;
    }
  });
  return (
    <div className={classNames(styles.wrap, "customMap")}>
      <Map
        ref={MapRef}
        center={new BMapGL.Point(104.07231042809258, 30.66346725218748)}
        mapStyleV2={{
          styleJson: mapStyle,
        }}
        maxZoom={20}
        enableScrollWheelZoom
        style={{
          width: "100%",
          height: "100%",
        }}
      >
        <AreaPolygon />
      </Map>
    </div>
  );
});

const ApiMap = MapApiLoaderHOC({ ak: "Mcf1eN6ulVr5pRLzZIiVoTHu7c5xWflG" })(
  BMap
);

const BMapView = () => {
  return (
    <div className={styles.container}>
      <div className={styles.scoreDisplay}>
        <div>成都市今日综合管理指数</div>
        <div className={styles.value}>95.5</div>
      </div>
      <ApiMap></ApiMap>
      <div className={styles.footer}>
        <img src={icon} className={styles.menu}></img>
        <img src={icon4} className={styles.status}></img>
      </div>
    </div>
  );
};

export default BMapView;
