import React, { useEffect, useState } from "react";
import styles from "./index.module.css";
import locationIcon from "@/assets/images/location.png";
import icon1 from "@/assets/images/icon1.png";
import { Steps, Image } from "antd-mobile";
import request from "umi-request";
import { useLocation } from "react-router-dom";
import dayjs from "dayjs";
import classNames from "classnames";

const token =
  "eyJ0eXAiOiJKV1QiLCJhbGciOiJIUzI1NiJ9.eyJpZCI6MywibG9naW5OYW1lIjoiamR5IiwidU5hbWUiOiLnm5HnnaPkurrlkZgiLCJ1Um9sZVR5cGUiOiJ1c2VyIiwiZGVwdENvZGUiOiIzIiwiZGVwdE5hbWUiOiLmiafms5XlsYAifQ.e_3V1ftd5xO6QDPjsPRBfHqnrxANz6uuf-DUYfyAvpY";

const { Step } = Steps;
export default function () {
  const location = useLocation();
  const [dataSource, setDataSource] = useState({});
  const [history, setHistory] = useState([]);
  const [type, setType] = useState("1");
  const [userId, setUserId] = useState();
  useEffect(() => {
    const params = new URLSearchParams(location.search);
    const id = params.get("id");
    if (id) {
      const type = params.get("userType");
      const userId = params.get("userId");
      setUserId(userId);
      setType(type);
      request
        .post("/apis/event-info/queryEventDetail", {
          headers: {
            token: token,
          },
          requestType: "form",
          data: {
            eventId: id,
          },
        })
        .then((res) => {
          console.log(res.data);
          setDataSource(res.data);
        });
      request
        .post("/apis/event-circulation-record/queryEventApproval", {
          headers: {
            token: token,
          },
          requestType: "form",

          data: {
            eventId: id,
          },
        })
        .then((res) => {
          let newList = [...res.data];
          setHistory(newList);
        });
    }
  }, []);

  const getStatus = (v) => {
    console.log(v);
    if (v == 2 || v == 3 || v == 10 || v == 4 || v == 5 || v == 6) {
      return "#c86c0d";
    }
    if (v == 8) {
      return "#00C822";
    }
    if (v == 7) {
      return "#949494";
    }
    return "#ODC895";
  };

  return (
    <div className={styles.container}>
      <div className={styles.topView}>
        <div className={styles.title}>
          {dataSource?.eventTitle}
          <div
            className={styles.caseStatus}
            style={{
              backgroundColor: getStatus(dataSource?.caseStatus),
            }}
          >
            {dataSource?.caseStatusText}
          </div>
        </div>
        <div>
          <div>
            <span className={styles.label}>案件类别：</span>
            <span className={styles.value}>{dataSource?.subTypeName}</span>
          </div>
          <div style={{ marginTop: 12 }}>
            <span className={styles.label}>案件来源：</span>
            <span className={styles.value}>
              {dataSource?.collectionModeName}
            </span>
          </div>
          <div style={{ marginTop: 12 }}>
            <span className={styles.label}>案件编码：</span>
            <span className={styles.value}>
              {dataSource?.standardEventNumber}
            </span>
          </div>
        </div>
      </div>
      <div className={styles.resultImgBox}>
        <div className={styles.imgBox}>
          <div className={styles.img}>
            <div className={styles.imgMark}>处置前</div>
            <Image
              fit="cover"
              src={dataSource?.reportFilePath}
              style={{ height: "100%", width: "100%", borderRadius: 14 }}
            ></Image>
          </div>
          {dataSource?.dealFilePath && dataSource?.dealFilePath.length > 0 ? (
            <div className={styles.img}>
              <div className={styles.imgMark_1}>处置后</div>
              <Image
                fit="cover"
                src={dataSource?.dealFilePath}
                style={{ height: "100%", width: "100%", borderRadius: 14 }}
              ></Image>
            </div>
          ) : undefined}
        </div>
        <div className={styles.location}>
          <img src={locationIcon} alt="" className={styles.locationIcon}></img>
          <div>{dataSource?.address}</div>
        </div>
      </div>

      <div className={styles.timeBox}>
        <div className={styles.leftTimeBox}>
          <img src={icon1} alt="" className={styles.statusIcon}></img>
          <div className={styles.statusText}>{dataSource?.caseStatusText}</div>
        </div>
        <div className={styles.rightTimeBox}>
          <span className={styles.timeValue}>{dataSource?.limitTimeText}</span>
        </div>
      </div>

      <div className={styles.subtitle}>案件流转</div>
      <Steps direction="vertical">
        {history.map((item) => (
          <Step
            title=""
            status="process"
            description={
              <div
                className={classNames(
                  styles.stepItem,
                  String(userId) === String(item.personId)
                    ? styles.itemActive
                    : undefined
                )}
              >
                <div className={styles.sourceName}>
                  {item.deptName} {item.personName}
                </div>
                <div className={styles.stepTime}>
                  {dayjs(item.createTime).format("YYYY-MM-DD HH:mm:ss")}
                </div>
                <div className={styles.stepItem_content}>
                  <div className={styles.remark}>
                    备注：{item?.operationRemark ?? "无"}
                  </div>
                  <div className={styles.sourceStatus}>
                    {item.operationText}
                  </div>
                </div>
              </div>
            }
          />
        ))}
      </Steps>
    </div>
  );
}
